==> pianosdk-16.248.0-py3-none-any.whl: pianosdk/publisher/api/publisher_term_custom_api.py <==
from datetime import datetime
from io import StringIO
from typing import TextIO, Dict, List, Union

from pianosdk.api_response import ApiResponse
from pianosdk.base_api import BaseApi
from pianosdk.configuration import Configuration
from pianosdk.httpwrap import HttpCallBack
from pianosdk.utils import _json_deserialize, _encode_parameter
from pianosdk.publisher.models.term import Term


class PublisherTermCustomApi(BaseApi):
    def __init__(self, config: Configuration, http_callback: HttpCallBack = None) -> None:
        super().__init__(config, http_callback)

    def create_custom_term(self, aid: str, rid: str, name: str, custom_require_user: bool = False, custom_default_access_period: int = None, description: str = None) -> ApiResponse[Term]:
        _url_path = '/api/v3/publisher/term/custom/create'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'rid': _encode_parameter(rid),
            'name': _encode_parameter(name),
            'custom_require_user': _encode_parameter(custom_require_user),
            'custom_default_access_period': _encode_parameter(custom_default_access_period),
            'description': _encode_parameter(description)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Term)
        return _result

    def update_custom_term(self, term_id: str, rid: str = None, name: str = None, custom_require_user: bool = None, custom_default_access_period: int = None, description: str = None) -> ApiResponse[Term]:
        _url_path = '/api/v3/publisher/term/custom/update'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'term_id': _encode_parameter(term_id),
            'rid': _encode_parameter(rid),
            'name': _encode_parameter(name),
            'custom_require_user': _encode_parameter(custom_require_user),
            'custom_default_access_period': _encode_parameter(custom_default_access_period),
            'description': _encode_parameter(description)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Term)
        return _result

==> pianosdk-16.589.0-py3-none-any.whl: pianosdk/publisher/api/publisher_term_custom_api.py <==
from datetime import datetime
from io import StringIO
from typing import TextIO, Dict, List, Union

from pianosdk.api_response import ApiResponse
from pianosdk.base_api import BaseApi
from pianosdk.configuration import Configuration
from pianosdk.httpwrap import HttpCallBack
from pianosdk.utils import _json_deserialize, _encode_parameter
from pianosdk.publisher.models.term import Term


class PublisherTermCustomApi(BaseApi):
    def __init__(self, config: Configuration, http_callback: HttpCallBack = None) -> None:
        super().__init__(config, http_callback)

    def create_custom_term(self, aid: str, rid: str, name: str, custom_default_access_period: int = None, description: str = None) -> ApiResponse[Term]:
        _url_path = '/api/v3/publisher/term/custom/create'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'aid': _encode_parameter(aid),
            'rid': _encode_parameter(rid),
            'name': _encode_parameter(name),
            'custom_default_access_period': _encode_parameter(custom_default_access_period),
            'description': _encode_parameter(description)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Term)
        return _result

    def update_custom_term(self, term_id: str, rid: str = None, name: str = None, custom_default_access_period: int = None, description: str = None) -> ApiResponse[Term]:
        _url_path = '/api/v3/publisher/term/custom/update'
        _query_url = self.config.get_base_url() + _url_path
        _query_parameters = {

        }

        _headers = {
            'api_token': self.config.api_token,
            'Accept': 'application/json'
        }

        _parameters = {
            'term_id': _encode_parameter(term_id),
            'rid': _encode_parameter(rid),
            'name': _encode_parameter(name),
            'custom_default_access_period': _encode_parameter(custom_default_access_period),
            'description': _encode_parameter(description)
        }

        _body = None
        _files = None

        _request = self.config.http_client.build_request('POST',
                                                         _query_url,
                                                         headers=_headers,
                                                         query_parameters=_query_parameters,
                                                         parameters=_parameters,
                                                         json=_body,
                                                         files=_files)
        _response = self._execute_request(_request)
        _result = _json_deserialize(_response, Term)
        return _result
